<?php

/*
Plugin Name: WPFTS Addon for Document Library Pro
Description: This plugin improves compatibility between WPFTS Pro and Document Library Pro plugins.
Version: 1.1.2
Tested up to: 6.0.2
Author: Epsiloncool
Author URI: https://e-wm.org
License: GPLv3
License URI: http://www.gnu.org/licenses/gpl-3.0.html
Text Domain: wpfts_lang
Domain Path: /languages/
*/

/**
 *  Copyright 2013-2022 Epsiloncool
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************
 *  I am thank you for the help by buying PRO version of this plugin 
 *  at https://fulltextsearch.org/ 
 *  It will keep me working further on this useful product.
 ******************************************************************************
 * 
 *  @copyright 2013-2022
 *  @license GPLv3
 *  @version 1.0.1
 *  @package Wordpress Fulltext Search Pro
 *  @author Epsiloncool <info@e-wm.org>
 */

/**
 * This addon is intended to be run with Wordpress Fulltext Search plugin
 * 
 */

/**
 * Use this hook to add some data to search index
 *
 * NOTICE: Please keep in a mind to REBUILD INDEX for those posts that was affected by any change in this code!
 */
add_filter('wpfts_index_post', function($index, $post)
{
	global $wpfts_core;

    // Basic tokens 
    /* 
     * This piece of code was commented out intentionally to display things
     * which was already done before in the caller code
    $index['post_title'] = $post->post_title;
    $index['post_content'] = strip_tags($post->post_content);
    */
    if ($post->post_type == 'dlp_document') {
	
		$link_type = get_post_meta($post->ID, '_dlp_document_link_type', true);
		$file_size = get_post_meta($post->ID, '_dlp_document_file_size', true);
		$file_id = get_post_meta($post->ID, '_dlp_attached_file_id', true);
		$link_url = get_post_meta($post->ID, '_dlp_direct_link_url', true);

		$local_url = false;
		if ($link_type === 'file') {
			// The attachment post
			if ($file_id > 0) {
				$ret = $wpfts_core->getCachedAttachmentContent($file_id);
				
				// Put file content to the index
				$index['linked_file_content'] = (isset($ret['post_content']) ? trim($ret['post_content']) : '').' ';
			}
			
		} elseif ($link_type === 'url') {
			// The link
			$local_url = $link_url;
			
			require_once $wpfts_core->root_dir.'/includes/wpfts_utils.class.php';

			if ($local_url && (strlen($local_url) > 0)) {
				$ret = WPFTS_Utils::GetCachedFileContent_ByLocalLink($local_url, false, false, true, $post->post_modified);	// External links enabled

				// Put file content to the index
				$index['linked_file_content'] = (isset($ret['post_content']) ? trim($ret['post_content']) : '').' ';	
			}
		} else {
			// Unknown link_type
			
		}
		

			
    } 
    return $index; 
}, 3, 2);

add_filter('wpfts_se_titlelink', function($r1, $post)
{
	
	if (isset($post['post_type']) && ($post['post_type'] == 'dlp_document')) {
		// Use direct link for titles
		
		$link = $r1['link']; 
		$post_id = $post['ID'];
		
		$link_type = get_post_meta($post_id, '_dlp_document_link_type', true);
		$file_size = get_post_meta($post_id, '_dlp_document_file_size', true);
		$file_id = get_post_meta($post_id, '_dlp_attached_file_id', true);
		$link_url = get_post_meta($post_id, '_dlp_direct_link_url', true);

		$local_url = false;
		if ($link_type === 'file') {
			// The attachment post
			if ($file_id > 0) {
				
				$link = wp_get_attachment_url($file_id);
			}
			
		} elseif ($link_type === 'url') {
			// The link
			$link = $link_url;
		} else {
			// Unknown link_type
			
		}
		
		$r1['link'] = $link;
		
	}

	return $r1;
}, 15, 2);

add_action('wp_head', function()
{
	ob_start();
	?>
	<script type="text/javascript">
	jQuery(document).ready(function()
	{
		jQuery('.et_pb_ajax_pagination_container a[href]').each(function(v)
		{
			var link = jQuery(this).attr('href');
			
			if (/\.pdf$/.test(link)) {
				jQuery(this).attr('target', '_blank');
			}
		});	
	});
	</script>
	<?php
	echo ob_get_clean();
});
